function varargout = clickMeEx(varargin)
% CLICKMEEX M-file for clickMeEx.fig
%
%   My first GUI example. Click the button to see the message change.
%   Dr. C. S. Tritt
%   1/7/07
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Copyright 2002-2003 The MathWorks, Inc.

% Edit the above text to modify the response to help clickMeEx

% Last Modified by GUIDE v2.5 07-Jan-2007 17:07:20

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @clickMeEx_OpeningFcn, ...
                   'gui_OutputFcn',  @clickMeEx_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before clickMeEx is made visible.
function clickMeEx_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to clickMeEx (see VARARGIN)

% Choose default command line output for clickMeEx
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes clickMeEx wait for user response (see UIRESUME)
uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = clickMeEx_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in theButton.
function theButton_Callback(hObject, eventdata, handles)
% hObject    handle to theButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA

% Added this line to create functionality - cst.
set(handles.theText, 'String', 'Clicked!');


% --- Executes on button press in exitButton.
function exitButton_Callback(hObject, eventdata, handles);
% hObject    handle to exitButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Added this line to create functionality - cst.
delete(handles.figure1);